import { FhirResource } from 'fhir/r4';
export declare enum FHIRDateAccuracy {
    YEAR = 0,
    YEAR_MONTH = 1,
    YEAR_MONTH_DAY = 2,
    YEAR_MONTH_DAY_TIME = 3
}
/**
 * A FHIR date. A FHIR date may not have all components provided.
 */
export declare class FHIRDate {
    /**
     * The parsed date as a JavaScript date object. The date is parsed into UTC,
     * so only the getUTC methods should be used to extract data from it.
     */
    readonly date: Date;
    /**
     * The degree of accuracy provided for the date. Dates can be missing parts.
     */
    readonly accuracy: FHIRDateAccuracy;
    /**
     * Whether or not the seconds was actually 60 and not 0. Leap seconds are
     * allowed in the FHIR date time spec! If given a time that ends in a 60,
     * the minute is left as-is, and the seconds are decreased to 59, and this
     * flag is set. Note that milliseconds are not changed! For almost all use
     * cases, it makes the most sense to ignore this flag.
     */
    readonly leapSecond: boolean;
    constructor(date: Date, accuracy: FHIRDateAccuracy, leapSecond?: boolean);
    /**
     * Parses a FHIR date. Throws an exception if the date is invalid.
     * @param value
     */
    static parse(value: string): FHIRDate;
}
/**
 * Checks to see if a given resource contains a requested profile.
 * @param resource the FHIR resource to check
 * @param profile the profile string to look up
 * @returns true if the profile exists on the resource
 */
export declare function resourceContainsProfile(resource: FhirResource, profile: string | RegExp): boolean;
